@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2020-2021 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Sublike::Builder 0.11;
+package XS::Parse::Sublike::Builder 0.16;
 
 use v5.14;
 use warnings;
@@ -38,10 +38,7 @@ distribution to be able to make use of C<XS::Parse::Sublike>.
 
 =cut
 
-my $XSParseSublike_h = do {
-   local $/;
-   readline DATA;
-};
+require XS::Parse::Sublike::Builder_data;
 
 =head1 FUNCTIONS
 
@@ -63,7 +60,7 @@ sub write_XSParseSublike_h
    open my $out, ">", "XSParseSublike.h" or
       die "Cannot open XSParseSublike.h for writing - $!\n";
 
-   $out->print( $XSParseSublike_h );
+   $out->print( XS::Parse::Sublike::Builder_data->XSPARSESUBLIKE_H );
 }
 
 =head2 extra_compiler_flags
@@ -157,34 +154,34 @@ struct XSParseSublikeHooks {
   bool (*filter_attr)    (pTHX_ struct XSParseSublikeContext *ctx, SV *attr, SV *val, void *hookdata);
 };
 
-static int (*parse_func)(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr);
+static int (*parse_xs_parse_sublike_func)(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr);
 #define xs_parse_sublike(hooks, hookdata, op_ptr)  S_xs_parse_sublike(aTHX_ hooks, hookdata, op_ptr)
 static int S_xs_parse_sublike(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr)
 {
-  if(!parse_func)
+  if(!parse_xs_parse_sublike_func)
     croak("Must call boot_xs_parse_sublike() first");
 
-  return (*parse_func)(aTHX_ hooks, hookdata, op_ptr);
+  return (*parse_xs_parse_sublike_func)(aTHX_ hooks, hookdata, op_ptr);
 }
 
-static void (*register_func)(pTHX_ const char *kw, const struct XSParseSublikeHooks *hooks, void *hookdata);
+static void (*register_xs_parse_sublike_func)(pTHX_ const char *kw, const struct XSParseSublikeHooks *hooks, void *hookdata);
 #define register_xs_parse_sublike(kw, hooks, hookdata) S_register_xs_parse_sublike(aTHX_ kw, hooks, hookdata)
 static void S_register_xs_parse_sublike(pTHX_ const char *kw, const struct XSParseSublikeHooks *hooks, void *hookdata)
 {
-  if(!register_func)
+  if(!register_xs_parse_sublike_func)
     croak("Must call boot_xs_parse_sublike() first");
 
-  return (*register_func)(aTHX_ kw, hooks, hookdata);
+  return (*register_xs_parse_sublike_func)(aTHX_ kw, hooks, hookdata);
 }
 
-static int (*parseany_func)(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr);
+static int (*parseany_xs_parse_sublike_func)(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr);
 #define xs_parse_sublike_any(hooks, hookdata, op_ptr)  S_xs_parse_sublike_any(aTHX_ hooks, hookdata, op_ptr)
 static int S_xs_parse_sublike_any(pTHX_ const struct XSParseSublikeHooks *hooks, void *hookdata, OP **op_ptr)
 {
-  if(!parseany_func)
+  if(!parseany_xs_parse_sublike_func)
     croak("Must call boot_xs_parse_sublike() first");
 
-  return (*parseany_func)(aTHX_ hooks, hookdata, op_ptr);
+  return (*parseany_xs_parse_sublike_func)(aTHX_ hooks, hookdata, op_ptr);
 }
 
 #define boot_xs_parse_sublike(ver) S_boot_xs_parse_sublike(aTHX_ ver)
@@ -198,13 +195,13 @@ static void S_boot_xs_parse_sublike(pTHX_ double ver) {
     croak("XS::Parse::Sublike ABI version mismatch - library provides %d, compiled for %d",
         abi_version, XSPARSESUBLIKE_ABI_VERSION);
 
-  parse_func = INT2PTR(int (*)(pTHX_ const struct XSParseSublikeHooks *, void *, OP**),
+  parse_xs_parse_sublike_func = INT2PTR(int (*)(pTHX_ const struct XSParseSublikeHooks *, void *, OP**),
       SvUV(get_sv("XS::Parse::Sublike::PARSE", 0)));
 
-  register_func = INT2PTR(void (*)(pTHX_ const char *, const struct XSParseSublikeHooks *, void *),
+  register_xs_parse_sublike_func = INT2PTR(void (*)(pTHX_ const char *, const struct XSParseSublikeHooks *, void *),
       SvUV(get_sv("XS::Parse::Sublike::REGISTER", 0)));
 
-  parseany_func = INT2PTR(int (*)(pTHX_ const struct XSParseSublikeHooks *, void *, OP**),
+  parseany_xs_parse_sublike_func = INT2PTR(int (*)(pTHX_ const struct XSParseSublikeHooks *, void *, OP**),
       SvUV(get_sv("XS::Parse::Sublike::PARSEANY", 0)));
 }
 
